==> mkdocs_iolanta_tables-0.1.3-py3-none-any.whl: mkdocs_iolanta_tables/plugin.py <==
from pathlib import Path
from typing import Any, Dict

from deepmerge import always_merger
from mkdocs.config import Config
from mkdocs.structure.files import Files
from mkdocs.structure.pages import Page

from iolanta.conversions import path_to_url
from mkdocs_iolanta_tables.models import TABLE
from octadocs.mixins import OctadocsMixin


class TablesPlugin(OctadocsMixin):
    """Render an HTML table from data presented in the graph."""

    namespaces = {
        'table': TABLE,
    }

    @property
    def templates_path(self) -> Path:
        """Templates associated with the plugin."""
        return Path(__file__).parent / 'templates'

    def context_url(self) -> str:
        path = Path(__file__).parent / 'yaml/ctx.yaml'
        return f'file://{path}'

    def on_config(self, config, **kwargs):
        """Adjust configuration."""
        super().on_config(config, **kwargs)

        # Make plugin's templates available to MkDocs
        config['theme'].dirs.append(str(self.templates_path))

        config['extra'].setdefault('contexts', []).append(
            Path(__file__).parent / 'yaml/context.yaml',
        )

    def on_files(self, files: Files, config: Config):
        super().on_files(files=files, config=config)

        self.iolanta.add(
            url=path_to_url(Path(__file__).parent / 'yaml/octadocs-table.yaml'),
            context=config['extra']['default_context'],
        )

    def on_page_context(
        self,
        context: Dict[str, Any],
        page: Page,
        **kwargs,
    ):
        """Make custom functions available to the template."""
        context.update({
            'table': TABLE,
        })

        return context

==> mkdocs_iolanta_tables-1.0.0-py3-none-any.whl: mkdocs_iolanta_tables/plugin.py <==
from pathlib import Path
from typing import Any, Dict

from deepmerge import always_merger
from mkdocs.config import Config
from mkdocs.structure.files import Files
from mkdocs.structure.pages import Page

from iolanta.conversions import path_to_url
from mkdocs_iolanta_tables.models import TABLE
from mkdocs_iolanta.mixins import OctadocsMixin


class TablesPlugin(OctadocsMixin):
    """Render an HTML table from data presented in the graph."""

    namespaces = {
        'table': TABLE,
    }

    @property
    def templates_path(self) -> Path:
        """Templates associated with the plugin."""
        return Path(__file__).parent / 'templates'

    def context_url(self) -> str:
        path = Path(__file__).parent / 'yaml/ctx.yaml'
        return f'file://{path}'

    def on_config(self, config, **kwargs):
        """Adjust configuration."""
        super().on_config(config, **kwargs)

        # Make plugin's templates available to MkDocs
        config['theme'].dirs.append(str(self.templates_path))

        config['extra'].setdefault('contexts', []).append(
            Path(__file__).parent / 'yaml/context.yaml',
        )

    def on_files(self, files: Files, config: Config):
        super().on_files(files=files, config=config)

        self.iolanta.add(
            url=path_to_url(Path(__file__).parent / 'yaml/octadocs-table.yaml'),
            context=config['extra']['default_context'],
        )

    def on_page_context(
        self,
        context: Dict[str, Any],
        page: Page,
        **kwargs,
    ):
        """Make custom functions available to the template."""
        context.update({
            'table': TABLE,
        })

        return context
